@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "persistent-soft" "20250805.1017"
+(define-package "persistent-soft" "20260202.1154"
   "Persistent storage, returning nil on failure."
-  '((pcache     "0.3.1")
+  '((cl-lib     "0.7.1")
+    (pcache     "0.3.1")
     (list-utils "0.4.2"))
-  :url "http://github.com/rolandwalker/persistent-soft"
-  :commit "24e41d1952bef5953ef0af2288de146265c7ee10"
-  :revdesc "24e41d1952be"
+  :url "https://github.com/rolandwalker/persistent-soft"
+  :commit "c94b34332529df573bad8a97f70f5a35d5da7333"
+  :revdesc "c94b34332529"
   :keywords '("data" "extensions")
   :authors '(("Roland Walker" . "walker@pobox.com"))
   :maintainers '(("Roland Walker" . "walker@pobox.com")))
